# Configure the OpenStack Provider
provider "openstack" {
        cloud = "d4s-pre"
}

variable "dns_zone" {
  type    = map(string)
  default = {
    zone_name = "cloud-pre.d4science.org."
    email = "postmaster@isti.cnr.it"
    description = "DNS primary zone for the d4s-pre-cloud project"
    ttl = 8600
    id = "c1a4b4bc-f167-4387-855d-38f0f99ca05c"
    }
}

variable "main_private_network" {
  type = map(string)
  default = {
    name = "d4s-pre-cloud-main"
    description = "D4Science Preprod private network (use this as the main network)"
    id = "23fd8a99-d551-4ada-8d3a-9859542ebb8c"
  } 
}

variable "main_private_subnet" {
  type = map(string)
  default = {
    name = "d4s-pre-cloud-main-subnet"
    description = "D4Science Preprod main private subnet"
    cidr = "10.1.32.0/22"
    gateway_ip = "10.1.32.1"
    allocation_start = "10.1.32.100"
    allocation_end = "10.1.35.254"
    }
}

variable "external_router" {
  type = map(string)
  default = {
    name = "d4s-pre-cloud-external-router"
    description = "D4Science Preprod main router"
    id = "cc26064a-bb08-4c0b-929f-d0cb39f934a3"
    }
}

variable "basic_services_ip" {
  type = map(string)
  default = {
    ca = "10.1.32.4"
    ca_cidr = "10.1.32.4/32"
    ssh_jump = "10.1.32.5"
    ssh_jump_cidr = "10.1.32.5/32"
    prometheus = "10.1.32.10"
    prometheus_cidr = "10.1.32.10/32"
    haproxy_l7_1 = "10.1.32.11"
    haproxy_l7_1_cidr = "10.1.32.11/32"
    haproxy_l7_2 = "10.1.32.12"
    haproxy_l7_2_cidr = "10.1.32.12/32"
    octavia_main = "10.1.32.20"
    octavia_main_cidr = "10.1.32.20/32"
  }
}

variable "main_haproxy_l7_ip" {
  type = list(string)
  default = ["10.1.32.11", "10.1.32.12"]
  
}
variable "ssh_sources" {
  type = map(string)
  default = {
    s2i2s_vpn_1_cidr = "146.48.28.10/32"
    s2i2s_vpn_2_cidr = "146.48.28.11/32"
    d4s_vpn_1_cidr = "146.48.122.27/32"
    d4s_vpn_2_cidr = "146.48.122.49/32"
    shell_d4s_cidr = "146.48.122.95/32"
    infrascience_net_cidr = "146.48.122.0/23"
  }
}

variable "octavia_information" {
  type = map(string)
  default = {
    main_lb_name = "d4s-pre-cloud-l4-load-balancer"
    main_lb_description = "Main L4 load balancer for the D4Science preproduction"
    swarm_lb_name = "d4s-pre-cloud-l4-swarm-load-balancer"
    octavia_flavor = "octavia_amphora-mvcpu-ha"
    octavia_flavor_id = "394988b5-6603-4a1e-a939-8e177c6681c7"
    main_lb_hostname = "main-lb"
    # The following aren't available when the module runs so we have to get them with the command
    # openstack --os-cloud d4s-pre port list -f value | grep octavia-lb-vrrp
    # This means that the execution will fail
    octavia_vrrp_ip_1 = "10.1.34.232"
    octavia_vrrp_ip_2 = "10.1.33.229"
    }
}
